@@ -7,7 +7,7 @@ from .utils.Danmaku import Danmaku, DmFontSize, DmMode
 from .utils.short import get_real_url
 from .utils.sync import sync
 from .utils.network_httpx import get_session, set_session
-from .utils.parse_link import parse_link
+from .utils.parse_link import parse_link, ResourceType
 
 HEADERS = {"User-Agent": "Mozilla/5.0", "Referer": "https://bilibili.com"}
 
@@ -21,6 +21,7 @@ __all__ = [
     "DmFontSize",
     "DmMode",
     "HEADERS",
+    "ResourceType",
     "aid2bvid",
     "app",
     "article",
