@@ -88,13 +88,13 @@ class Article:
         """
         转换为 Markdown
 
-        请先调用 get_content()
+        请先调用 fetch_content()
 
         Returns:
             str: Markdown 内容
         """
         if not self.__has_parsed:
-            raise ApiException("请先调用 get_content()")
+            raise ApiException("请先调用 fetch_content()")
 
         content = "".join([node.markdown() for node in self.__children])
 
@@ -106,13 +106,13 @@ class Article:
         """
         转换为 JSON 数据
 
-        请先调用 get_content()
+        请先调用 fetch_content()
 
         Returns:
             dict: JSON 数据
         """
         if not self.__has_parsed:
-            raise ApiException("请先调用 get_content()")
+            raise ApiException("请先调用 fetch_content()")
 
         return {
             "type": "Article",
@@ -209,8 +209,8 @@ class Article:
                             node.children = parse(e)
                         else:
                             if e.text != "":
-                                #print(e.text.replace("\n", ""))
-                                #print()
+                                # print(e.text.replace("\n", ""))
+                                # print()
                                 node = TextNode(e.text)
                                 # print("Add a text node: ", e.text)
                                 node_list.append(node)
@@ -525,7 +525,7 @@ class BoldNode(Node):
         t = "".join([node.markdown() for node in self.children])
         if len(t) == 0:
             return ""
-        return f" **{t}**"
+        return f" **{t.lstrip().rstrip()}**"
 
     def json(self):
         return {
